# Generated by Django 2.2.18 on 2021-04-15 16:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_community', '0007_auto_20210324_1146'),
    ]

    operations = [
        migrations.AlterField(
            model_name='community',
            name='name',
            field=models.CharField(blank=True, help_text="Changing a community's name is highly discouraged", max_length=255, null=True),
        ),
    ]
