# Generated by Django 2.2.18 on 2021-03-23 10:21

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_community', '0003_auto_20210218_1145'),
    ]

    operations = [
        migrations.AlterField(
            model_name='communitycircle',
            name='circle',
            field=models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='community', to='djangoldp_circle.Circle'),
        ),
        migrations.AlterField(
            model_name='communityjoboffer',
            name='joboffer',
            field=models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='community', to='djangoldp_joboffer.JobOffer'),
        ),
        migrations.AlterField(
            model_name='communityproject',
            name='project',
            field=models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='community', to='djangoldp_project.Project'),
        ),
    ]
