# Generated by Django 2.2.18 on 2021-03-24 10:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_community', '0006_auto_20210324_1113'),
    ]

    operations = [
        migrations.RenameField(
            model_name='communityaddress',
            old_name='address',
            new_name='address_line1',
        ),
        migrations.AddField(
            model_name='communityaddress',
            name='address_line2',
            field=models.CharField(blank=True, default='', max_length=254, null=True),
        ),
    ]
