# Generated by Django 2.2.18 on 2021-02-17 11:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_community', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='community',
            name='allow_self_registration',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='community',
            name='logo',
            field=models.URLField(blank=True, null=True),
        ),
    ]
