# Generated by Django 2.2.18 on 2021-03-24 10:13

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_community', '0005_communityaddress_communityprofile'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='communityaddress',
            options={'default_permissions': ['add', 'change', 'delete', 'view', 'control'], 'verbose_name': 'community address', 'verbose_name_plural': 'community addresses'},
        ),
        migrations.AlterModelOptions(
            name='communityprofile',
            options={'default_permissions': ['add', 'change', 'delete', 'view', 'control'], 'verbose_name': 'community profile', 'verbose_name_plural': 'community profiles'},
        ),
        migrations.RenameField(
            model_name='communityaddress',
            old_name='lon',
            new_name='lng',
        ),
    ]
