# Generated by Django 2.2.18 on 2021-02-18 10:45

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_community', '0002_auto_20210217_1205'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='community',
            options={'default_permissions': ['add', 'change', 'delete', 'view', 'control'], 'ordering': ['slug'], 'verbose_name': 'community', 'verbose_name_plural': 'communities'},
        ),
        migrations.AlterModelOptions(
            name='communitycircle',
            options={'default_permissions': ['add', 'change', 'delete', 'view', 'control'], 'verbose_name': 'community circle', 'verbose_name_plural': 'community circles'},
        ),
        migrations.AlterModelOptions(
            name='communityjoboffer',
            options={'default_permissions': ['add', 'change', 'delete', 'view', 'control'], 'verbose_name': 'community job offer', 'verbose_name_plural': 'community job offers'},
        ),
        migrations.AlterModelOptions(
            name='communitymember',
            options={'default_permissions': ['add', 'change', 'delete', 'view', 'control'], 'verbose_name': 'community member', 'verbose_name_plural': 'community members'},
        ),
        migrations.AlterModelOptions(
            name='communityproject',
            options={'default_permissions': ['add', 'change', 'delete', 'view', 'control'], 'verbose_name': 'community project', 'verbose_name_plural': 'community projects'},
        ),
        migrations.AlterField(
            model_name='community',
            name='name',
            field=models.CharField(blank=True, help_text="Changing a community's name is highly discouraged", max_length=255),
        ),
    ]
